#
# spec file for package bibview
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bibview
BuildRequires:  imake
BuildRequires:  xaw3d-devel
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xt)
Provides:       bibvw15
Version:        2.2
Release:        1011.2
Summary:        X11 Front-End for BibTeX Databases
License:        SUSE-Permissive
Group:          Productivity/Publishing/TeX/Utilities
Source:         bibview-2.2.tar.gz
Patch0:         bibview-2.2.dif
Patch1:         bibview-C99.dif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define _x11data    %{_datadir}/X11
%define _appdefdir  %{_x11data}/app-defaults

%description
Using bibview, entries in several BiB databases can be moved,
manipulated, created, and searched.

%prep
%autosetup -p0

%build
    xmkmf -a
    make XAWLIB=-lXaw3d %{?_smp_mflags}

%install
    make DESTDIR=%{buildroot} install
    make DESTDIR=%{buildroot} install.man
    mkdir -p %{buildroot}%{_x11data}/de/app-defaults
    install -c -m 0444 BibView.ger.ad   %{buildroot}%{_x11data}/de/app-defaults/BibView
    install -c -m 0444 BibView-color.ad %{buildroot}%{_x11data}/de/app-defaults/BibView-color

%files
%defattr(-,root,root,755)
%{_bindir}/bibview
%dir %{_x11data}/de/
%dir %{_x11data}/de/app-defaults/
%dir %{_appdefdir}
%config %{_appdefdir}/BibView
%config %{_appdefdir}/BibView-color
%config %{_x11data}/de/app-defaults/BibView
%config %{_x11data}/de/app-defaults/BibView-color
%doc %{_mandir}/man1/bibview.1x.gz

%changelog
* Fri Aug 16 2024 Martin Jambor <mjambor@suse.com>
- Add bibview-C99.dif adding missing includes so that all called
  functions are properly declared and the package builds with
  GCC 14.
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
-  Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Tue Feb 19 2019 Dr. Werner Fink <werner@suse.de>
- Correct documentation as there is no X11R6 anymore for a long time
* Tue Feb 20 2018 crrodriguez@opensuse.org
- Remove xorg-x11-devel from BuildRequires
* Mon Feb 20 2012 coolo@suse.com
- buildrequire xorg-x11 for directory ownership
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Fri Jun  1 2007 dmueller@suse.de
- fix buildrequires
* Thu Nov 30 2006 werner@suse.de
- Remove broken error handler declaration type
* Wed Aug  2 2006 werner@suse.de
- Make it build with X11R7
- Make german app-defaults file depending on LANG variable
- Use Xaw3d to get see 3d menue
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Apr 27 2004 werner@suse.de
- Avoid compiler warnings
- Use mkstemp(3) instead of tempnam(3)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Jun 13 2003 kukuk@suse.de
- fix filelist
* Thu Jun 12 2003 coolo@suse.de
- use BuildRoot
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Sep 20 2000 werner@suse.de
- Workaround to avoid `XtMakeGeometryRequest - parent not composite'
  messages instead of working program. Done by simply adding the
  old version of _XtMakeGeometryRequest of Xfree86[tm]-3.3.6.
* Fri Jul 14 2000 werner@suse.de
- fix bug in annotation handling with update to bibview 2.2
- Use getcwd instead of getwd
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
